# Integer module

## Miscellaneous integer functions
::: pqlattice.integer.eea

::: pqlattice.integer.is_prime

---

## `ModIntRing` class for modular arithmetic operations
::: pqlattice.integer.ModIntRing

---

## Free functions for modular arithmetic operations
::: pqlattice.integer.mod

::: pqlattice.integer.cmodl

::: pqlattice.integer.cmodr

::: pqlattice.integer.modinv

::: pqlattice.integer.modpow
